@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author Roberto Cavada <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 import _importer
@@ -54,9 +54,10 @@ class MyCtrl (Controller):
         self.model.reset_value = sb.get_value_as_int()
         return
     
-    # observable properties    
-    def property_counter_value_change(self, model, old, new):
-        self.view.set_counter_value(new)
+    # observable properties
+    @Controller.observe("counter", assign=True)
+    def counter_change(self, model, prop_name, info):
+        self.view.set_counter_value(info.new)
         return
     
     pass # end of class
