@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 import utils._importer
 from gtkmvc import Controller
@@ -51,6 +51,7 @@ class AboutCtrl (Controller):
         sw = self.view['sw_scroller']
         if sw is None: return False # destroyed!        
         vadj = sw.get_vadjustment()
+        if vadj is None: return False
         val = vadj.get_value()
         
         # is scrolling over?
@@ -74,8 +75,9 @@ class AboutCtrl (Controller):
     # ----------------------------------------
     #          observable properties
     # ----------------------------------------
-    def property_credits_value_change(self, model, old, new):
-        self.view.set_text(new)
+    @Controller.observe("credits", assign=True)
+    def credits_change(self, m, n, info):
+        self.view.set_text(info.new)
         return
 
     pass # end of class
