@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 import utils._importer
@@ -70,9 +70,10 @@ class AmountCtrl (Controller):
     # ----------------------------------------
     #          observable properties
     # ----------------------------------------
-    def property_amount_value_change(self, m, old, new):
+    @Controller.observe("amount", assign=True)
+    def amount_change(self, m, n, info):
         if self.__changing_amount: return
-        self.view['sb_amount'].set_value(new)
+        self.view['sb_amount'].set_value(info.new)
         return
     pass # end of class
 
