@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 import utils._importer
@@ -58,13 +58,15 @@ class ConverterCtrl (Controller):
     def on_button_convert_clicked(self, btn):
         self.model.convert()
         return
-
     
     # ----------------------------------------
     #          observable properties
     # ----------------------------------------
-    def property_can_convert_value_change(self, m, old, new):
-        if old != new: self.view['button_convert'].set_sensitive(new)
+    @Controller.observe("can_convert", assign=True)
+    def can_convert_change(self, m, pname, info):
+        if info.old != info.new:
+            self.view['button_convert'].set_sensitive(info.new)
+            pass
         return
     
     pass # end of class
