@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author Roberto Cavada <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 # ----------------------------------------------------------------------
@@ -44,7 +44,6 @@ class MyModel (Model):
 
     sgn = observable.Signal()
     __observables__ = ("sgn",)
-
     pass
 
 
@@ -55,8 +54,9 @@ class MyObserver (Observer):
         return
 
     # notification
-    def property_sgn_signal_emit(self, model, arg):
-        print "Signal!", model, arg
+    @Observer.observe("sgn", signal=True)
+    def signal_emit(self, model, prop_name, info):
+        print "Signal!", model, info.arg
         return
 
     pass # end of class
