@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2006 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author Roberto Cavada <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 from gtkmvc import Controller
@@ -40,14 +40,16 @@ class MyController (Controller):
         return True
     
     # observd properties
-    def property_counter_value_change(self, model, old, new):
-        self.view.set_label("%d" % new)
+    @Controller.observe("counter", assign=True)
+    def counter_change(self, model, prop_name, info):
+        self.view.set_label("%d" % info.new)
         return
 
-    def property_busy_value_change(self, model, old, new):
-        if new != old:
-            self.view['button'].set_sensitive(not new)
-            if not new: self.view['button'].grab_focus()
+    @Controller.observe("busy", assign=True)
+    def busy_change(self, model, prop_name, info):
+        if info.new != info.old:
+            self.view['button'].set_sensitive(not info.new)
+            if not info.new: self.view['button'].grab_focus()
         return
 
     pass # end of class
