@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2007 by Roberto Cavada
 #
@@ -18,8 +18,8 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author Roberto Cavada <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 import types
@@ -31,6 +31,33 @@ from gtkmvc.adapters.default import *
 from gtkmvc.observer import Observer
 from gtkmvc.support.wrappers import ObsMapWrapper
 
+# Just importing gtk only works for Builder, not glade.
+try: import gtk.glade
+except ImportError: pass
+
+# this tries solving the issue in gtk about Builder not setting name
+# correctly. See https://bugzilla.gnome.org/show_bug.cgi?id=591085
+def _get_name(widget):
+    try:
+        name = gtk.glade.get_widget_name(widget)
+        if name is not None:
+            # Widget was loaded from XML.
+            return name
+    except AttributeError:
+        # Library wasn't successfully imported.
+        pass
+
+    try:
+        # Will be kind instead of name if it wasn't loaded from XML :(
+        return gtk.Buildable.get_name(widget)
+    except AttributeError:
+        # Gtk is too old.
+        pass
+    
+    raise NotImplementedError("StaticContainerAdapter doesn't support "
+                              "manually created widgets")
+
+
 # ----------------------------------------------------------------------
 class StaticContainerAdapter (UserClassAdapter):
     """
@@ -50,18 +77,22 @@ class StaticContainerAdapter (UserClassAdapter):
     occur in the view-side.
     """
     def __init__(self, model, prop_name,
-                 prop_read=None, prop_write=None, value_error=None):
+                 prop_read=None, prop_write=None, value_error=None,
+                 spurious=False):
 
         UserClassAdapter.__init__(self, model, prop_name,
                                   lambda c,i: c.__getitem__(i),
                                   lambda c,v,i: c.__setitem__(i,v),
                                   prop_read, prop_write, 
-                                  value_error)
+                                  value_error, spurious)
 
         prop =  Adapter._get_property(self)
+
         #prop =  self._get_property() # bug fix reported by A. Dentella
         if not (hasattr(prop, "__getitem__") and
                 hasattr(prop, "__setitem__")):
+            # before giving up, unregisters itself as an observer
+            self.relieve_model(model)
             raise TypeError("Property " + self._prop_name +
                             " is not a valid container")
 
@@ -96,7 +127,7 @@ class StaticContainerAdapter (UserClassAdapter):
 
         # prepares the mappings:
         for idx, w in enumerate(self._widgets):
-            if self._prop_is_map: idx=w.get_name()
+            if self._prop_is_map: idx=_get_name(w)
             self._idx2wid[idx] = w
             self._wid2idx[w] = idx
             pass
@@ -185,7 +216,7 @@ class StaticContainerAdapter (UserClassAdapter):
             val = []
             for w in self._widgets:
                 if par.has_key(w): val.append(par[w])
-                elif par.has_key(w.get_name()): val.append(par[w.get_name()])
+                elif par.has_key(_get_name(w)): val.append(par[_get_name(w)])
                 else: val.append(None)
                 pass
             par = val
