@@ -1,4 +1,4 @@
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (c) 2005 by Roberto Cavada
 #
@@ -18,32 +18,47 @@
 #  Boston, MA 02110, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author Roberto Cavada <cavada@fbk.eu>.
-#  Please report bugs to <cavada@fbk.eu>.
+#  or email to the author Roberto Cavada <roboogle@gmail.com>.
+#  Please report bugs to <roboogle@gmail.com>.
 
 
 from gtkmvc.observer import Observer
+from gtkmvc.support.log import logger
+from gtkmvc.support.exceptions import TooManyCandidatesError
+
 import types
 import gobject
+import sys
 
 class Controller (Observer):
-    """
-    We put all of our gtk signal handlers into a class.  This lets
-    us bind all of them at once, because their names are in the
-    class dict.  This class automatically register its instances as
-    observers into the corresponding model.  Also, when a view is
-    passed, method register_view got called, which can be
-    oveloaded in order to connect signals and perform other specific
-    operation. A controller possibly handles and contains also a set
-    of adapters that makes easier to connect widgets and observable
-    properties into the model.
+    def __init__(self, model, view, spurious=False, auto_adapt=False):
+        """
+        Two positional and two optional keyword arguments.
+        
+        *model* will have the new instance registered as an observer.
+        It is made available as an attribute.
+        
+        *view* may contain signal connections loaded from XML. The handler
+        methods have to exist in this class.
+        
+        *spurious* denotes whether notifications in this class will be called
+        if a property of *model* is set to the same value it already has.
+        
+        *auto_adapt* denotes whether to call :meth:`adapt` with no arguments
+        as part of the view registration process.
 
-    parameter spurious controls the way spurious value change
-    notifications are handled. If True, assignments to observable
-    properties that do not actually change the value are
-    notified anyway."""
+        View registration consists of connecting signal handlers,
+        :meth:`register_view` and :meth:`register_adapters`, and is scheduled
+        with the GTK main loop. It happens as soon as possible but after the
+        constructor returns. When it starts *view* is available as an
+        attribute.
+        """
+        # In 1.99.0 the third parameter was optional. Now the interpreter will
+        # raise if it isn't given.
+        if view in (True, False):
+            raise NotImplementedError("This version of GTKMVC does not"
+                " support the 1.2 API")
 
-    def __init__(self, model, view=None, spurious=False, auto_adapt=False):
         Observer.__init__(self, model, spurious)
 
         self.model = model
@@ -53,7 +68,7 @@ class Controller (Observer):
         self.__user_props = set()
         self.__auto_adapt = auto_adapt
         
-        if view: gobject.idle_add(self._idle_register_view, view, priority=gobject.PRIORITY_HIGH)
+        gobject.idle_add(self._idle_register_view, view, priority=gobject.PRIORITY_HIGH)
         return
 
     def _idle_register_view(self, view):
@@ -70,10 +85,11 @@ class Controller (Observer):
 
     def register_view(self, view):
         """
-        This method is called by the framework when registering a
-        view. Derived classes can exploit this call to connect
-        signals manually, create and connect treeview, textview,
-        etc.
+        This does nothing. Subclasses can override it to connect signals
+        manually or modify widgets loaded from XML, like adding columns to a
+        TreeView. No super call necessary.
+        
+        *view* is a shortcut for ``self.view``.
         """
         assert(self.model is not None)
         assert(self.view is not None)
@@ -81,12 +97,8 @@ class Controller (Observer):
 
     def register_adapters(self):
         """
-        This method is called by register_view during view
-        registration process, when it is time to possibly create all
-        adapters. model and view can safely be taken from self.model
-        and self.view. Derived classes can specilize this method. In
-        this implementation the method does auto-adaptation if
-        requested.
+        This does nothing. Subclasses can override it to create adapters.
+        No super call necessary.
         """
         assert(self.model is not None)
         assert(self.view is not None)
@@ -94,45 +106,43 @@ class Controller (Observer):
 
     def adapt(self, *args):
         """
-        Adapts a set of (observable) properties and a set of
-        widgets, by connecting them.
+        There are four ways to call this:
 
-        This method can be used to simplify the creation of one or
-        more adapters, by letting the framework do most of the work
-        needed to connect ('adapt') properties from one hand, and
-        widgets on the other.
+        .. method:: adapt()
+           :noindex:
 
-        This method is provided in four flavours:
+           Take properties from the model for which ``adapt`` has not yet been
+           called, match them to the view by name, and create adapters fitting
+           for the respective widget type.
+           
+           That information comes from :mod:`gtkmvc.adapters.default`.
+           See :meth:`_find_widget_match` for name patterns.
 
-        1. No arguments. All properties in observed model will be
-           checked for possible widgets to be adapted with.
+           .. versionchanged:: 1.99.1
+              Allow incomplete auto-adaption, meaning properties for which no
+              widget is found.
 
-        2. An instance of an Adapter class can be created by the
-           caller and passed as a unique argument. The adapter must
-           be already fully configured.
+        .. method:: adapt(ad)
+           :noindex:
+        
+           Keep track of manually created adapters for future ``adapt()``
+           calls.
+        
+           *ad* is an adapter instance already connected to a widget.
 
-        3. The name of a model's property is passed as a unique
-           argument.  A correponding widget name is searched and if
-           found, an adapter is created. Name matching is performed
-           by searching into view's widget names for words that end
-           with the given property name. Matching is case
-           insensitive and words can be separated by spaces,
-           underscore (_) and CapitalizedWords. For example property
-           'prop' will match widget 'cb_prop'. If no matches or
-           multiple matches are found, a ValueError will be raised.
-           The way names are matched can be customized by deriving
-           method match_prop_name.
+        .. method:: adapt(prop_name)
+           :noindex:
 
-        4. Two strings can be passed, respectively containing the
-           name of an observable property in the model, and the name
-           of a widget in the view.
+           Like ``adapt()`` for a single property.
 
-        Flavour 2 allows for a full control, but flavour 1, 3 and 4
-        make easier to create adpaters with basic (default)
-        behaviour.
+           *prop_name* is a string.
 
-        This method can be called into the method register_adapters
-        which derived classes can specialise.
+        .. method:: adapt(prop_name, wid_name)
+           :noindex:
+
+           Like ``adapt(prop_name)`` but without widget name matching.
+           
+           *wid_name* has to exist in the view.
         """
         
         # checks arguments
@@ -144,11 +154,24 @@ class Controller (Observer):
             props = self.model.get_properties()
             # matches all properties not previoulsy adapter by the user:
             for prop_name in filter(lambda p: p not in self.__user_props, props):
-                wid_name = self.__find_widget_match(prop_name)
-                #print "Auto-adapting property",prop_name, "and widget", wid_name
-                adapters += self.__create_adapters__(prop_name, wid_name)                
+                try: wid_name = self._find_widget_match(prop_name)
+                except TooManyCandidatesError, e:
+                    # multiple candidates, gives up
+                    raise e
+                except ValueError, e: 
+                    # no widgets found for given property, continue after emitting a warning
+                    if e.args:
+                        logger.warn(e[0])
+                    else:
+                        logger.warn("No widget candidates match property '%s'"
+                            % prop_name)
+                else:
+                    logger.debug("Auto-adapting property %s and widget %s" % \
+                                     (prop_name, wid_name))
+                    adapters += self.__create_adapters__(prop_name, wid_name)                
+                    pass
                 pass
-
+            
         elif n == 1: #one argument
             from gtkmvc.adapters.basic import Adapter
             
@@ -156,10 +179,10 @@ class Controller (Observer):
 
             elif isinstance(args[0], types.StringType):
                 prop_name = args[0]
-                wid_name = self.__find_widget_match(prop_name)
+                wid_name = self._find_widget_match(prop_name)
                 adapters = self.__create_adapters__(prop_name, wid_name)
                 pass
-            else: raise TypeError("Argument of adapt() must be an Adapter or a string")
+            else: raise TypeError("Argument of adapt() must be either an Adapter or a string")
 
         else: # two arguments
             if not (isinstance(args[0], types.StringType) and
@@ -179,11 +202,21 @@ class Controller (Observer):
         
         return
 
-    def __find_widget_match(self, prop_name):
-        """Given a property name, searches into the view for a
-        possible corresponding widget to adapt with. This is called by
-        adapt. Returns the matching candidate widget name"""
+    def _find_widget_match(self, prop_name):
+        """
+        Used to search ``self.view`` when :meth:`adapt` is not given a widget 
+        name.
+        
+        *prop_name* is the name of a property in the model.
+        
+        Returns a string with the best match. Raises
+        :class:`TooManyCandidatesError` or ``ValueError`` when nothing is
+        found.
 
+        Subclasses can customise this. No super call necessary. The default
+        implementation converts *prop_name* to lower case and allows prefixes
+        like ``entry_``.
+        """
         names = []
         for wid_name in self.view:
             # if widget names ends with given property name: we skip
@@ -191,9 +224,13 @@ class Controller (Observer):
             if wid_name.lower().endswith(prop_name.lower()): names.append(wid_name)
             pass
 
-        if len(names) != 1:
-            raise ValueError("%d widget candidates match property '%s': %s" % \
-                                 (len(names), prop_name, names))
+        if len(names) == 0:
+            raise ValueError("No widget candidates match property '%s': %s" % \
+                                 (prop_name, names))
+
+        if len(names) > 1:
+            raise TooManyCandidatesError("%d widget candidates match property '%s': %s" % \
+                                             (len(names), prop_name, names))
         
         return names[0]
 
@@ -210,18 +247,17 @@ class Controller (Observer):
             dic[name] = method
             pass
 
-        for xml in self.view.xmlWidgets: xml.signal_autoconnect(dic) 
+        # autoconnects glade in the view (if available any)
+        for xml in self.view.glade_xmlWidgets: xml.signal_autoconnect(dic)
+
+        # autoconnects builder if available
+        if self.view._builder is not None:
+            self.view._builder.connect_signals(dic)
+            pass
+        
         return
 
     
-    def __match_prop_name(self, prop_name, wid_name):
-        """
-        Used internally when searching for a suitable widget. To customize
-        its behaviour, re-implement this method into derived classes
-        """
-        return 
-
-
     def __create_adapters__(self, prop_name, wid_name):
         """
         Private service that looks at property and widgets types,
@@ -241,21 +277,27 @@ class Controller (Observer):
         if isinstance(wid, gtk.Calendar):
             # calendar creates three adapter for year, month and day
             ad = RoUserClassAdapter(self.model, prop_name,
-                                    lambda d: d.year, lambda d,y: d.replace(year=y))
+                                    lambda d: d.year,
+                                    lambda d,y: d.replace(year=y),
+                                    spurious=self.accepts_spurious_change())
             ad.connect_widget(wid, lambda c: c.get_date()[0],
                               lambda c,y: c.select_month(c.get_date()[1], y),
                               "day-selected")
             res.append(ad) # year
             
             ad = RoUserClassAdapter(self.model, prop_name,
-                                    lambda d: d.month, lambda d,m: d.replace(month=m))
+                                    lambda d: d.month,
+                                    lambda d,m: d.replace(month=m),
+                                    spurious=self.accepts_spurious_change())
             ad.connect_widget(wid, lambda c: c.get_date()[1]+1,
                               lambda c,m: c.select_month(m-1, c.get_date()[0]),
                               "day-selected")
             res.append(ad) # month
 
             ad = RoUserClassAdapter(self.model, prop_name,
-                                  lambda d: d.day, lambda d,v: d.replace(day=v))
+                                    lambda d: d.day,
+                                    lambda d,v: d.replace(day=v),
+                                    spurious=self.accepts_spurious_change())
             ad.connect_widget(wid, lambda c: c.get_date()[2],
                               lambda c,d: c.select_day(d),
                               "day-selected")
@@ -264,13 +306,15 @@ class Controller (Observer):
 
             
         try: # tries with StaticContainerAdapter
-            ad = StaticContainerAdapter(self.model, prop_name)
+            ad = StaticContainerAdapter(self.model, prop_name,
+                                        spurious=self.accepts_spurious_change())
             ad.connect_widget(wid)
             res.append(ad)
             
         except TypeError:
             # falls back to a simple adapter
-            ad = Adapter(self.model, prop_name)
+            ad = Adapter(self.model, prop_name,
+                         spurious=self.accepts_spurious_change())
             ad.connect_widget(wid)
             res.append(ad)
             pass
