@@ -1,5 +1,5 @@
 #  -------------------------------------------------------------------------
-#  Author: Roberto Cavada <cavada@fbk.eu>
+#  Author: Roberto Cavada <roboogle@gmail.com>
 #
 #  Copyright (C) 2006 by Roberto Cavada
 #
@@ -19,15 +19,37 @@
 #  Boston, MA 02110, USA.ridge, MA 02139, USA.
 #
 #  For more information on pygtkmvc see <http://pygtkmvc.sourceforge.net>
-#  or email to the author <cavada@fbk.eu>.
+#  or email to the author <roboogle@gmail.com>.
 #  -------------------------------------------------------------------------
 
 
-from support import decorators
+from support import decorators, log
 from support.wrappers import ObsWrapperBase
 
 # ----------------------------------------------------------------------
 class Observable (ObsWrapperBase):
+
+    @classmethod
+    @decorators.good_classmethod_decorator
+    def observed(cls, _func):
+        """
+        Decorate methods to be observable. If they are called on an instance
+        stored in a property, the model will emit before and after
+        notifications.
+        """
+
+        def wrapper(*args, **kwargs):
+            self = args[0]
+            assert(isinstance(self, Observable))
+            
+            self._notify_method_before(self, _func.__name__, args, kwargs)
+            res = _func(*args, **kwargs)
+            self._notify_method_after(self, _func.__name__, res, args, kwargs)
+            return res    
+
+        return wrapper
+    
+
     def __init__(self):
         ObsWrapperBase.__init__(self)
         return
@@ -36,12 +58,10 @@ class Observable (ObsWrapperBase):
 
 @decorators.good_decorator
 def observed(func):
-    """Use this decorator to make your class methods observable.
-    
-    Your observer will receive at most two notifications:
-    - property_<name>_before_change
-    - property_<name>_after_change
+    """
+    Just like :meth:`Observable.observed`.
 
+    .. deprecated:: 1.99.1
     """
 
     def wrapper(*args, **kwargs):
@@ -52,6 +72,9 @@ def observed(func):
         res = func(*args, **kwargs)
         self._notify_method_after(self, func.__name__, res, args, kwargs)
         return res    
+
+    log.logger.warning("Decorator observable.observed is deprecated:"
+                       "use Observable.observed instead")
     return wrapper
 
 
@@ -64,7 +87,9 @@ class Signal (Observable):
 
     def emit(self, arg=None):
         """Emits the signal, passing the optional argument"""
-        return self.__get_model__().notify_signal_emit(
-            self.__get_prop_name__(), arg)
+        for model,name in self.__get_models__():
+            model.notify_signal_emit(name, arg)
+            pass
+        return
     pass # end of class
 
